@@ -5,7 +5,7 @@ use crate::common;
 use rand::seq::SliceRandom;
 
 /// Load the front page in English and all static assets found on the page.
-pub async fn front_page_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn front_page_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("").await?;
     goose_eggs::validate_and_load_static_assets(user, goose, &goose_eggs::Validate::title("Home"))
         .await?;
@@ -14,7 +14,7 @@ pub async fn front_page_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load recipe listing in English and all static assets found on the page.
-pub async fn recipe_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn recipe_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("en/recipes/").await?;
     goose_eggs::validate_and_load_static_assets(
         user,
@@ -27,7 +27,7 @@ pub async fn recipe_listing_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random recipe in English and all static assets found on the page.
-pub async fn recipe_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn recipe_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::Recipe);
     let recipe = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(recipe.unwrap().url_en).await?;
@@ -42,7 +42,7 @@ pub async fn recipe_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load article listing in English and all static assets found on the page.
-pub async fn article_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn article_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let goose = user.get("en/articles/").await?;
     goose_eggs::validate_and_load_static_assets(
         user,
@@ -55,7 +55,7 @@ pub async fn article_listing_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random article in English and all static assets found on the page.
-pub async fn article_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn article_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::Article);
     let article = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(article.unwrap().url_en).await?;
@@ -70,7 +70,7 @@ pub async fn article_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random basic page in English and all static assets found on the page.
-pub async fn basic_page_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn basic_page_en(user: &mut GooseUser) -> GooseTaskResult {
     let nodes = common::get_nodes(&common::ContentType::BasicPage);
     let page = nodes.choose(&mut rand::thread_rng());
     let goose = user.get(page.unwrap().url_en).await?;
@@ -85,7 +85,7 @@ pub async fn basic_page_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load a random node by nid in English and all static assets found on the page.
-pub async fn page_by_nid(user: &GooseUser) -> GooseTaskResult {
+pub async fn page_by_nid(user: &mut GooseUser) -> GooseTaskResult {
     // Randomly select a content type.
     let content_types = vec![
         common::ContentType::Article,
@@ -111,14 +111,14 @@ pub async fn page_by_nid(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Anonymously load the contact form in English and POST feedback.
-pub async fn anonymous_contact_form_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn anonymous_contact_form_en(user: &mut GooseUser) -> GooseTaskResult {
     common::anonymous_contact_form(user, true).await?;
 
     Ok(())
 }
 
 // Pick a random word from the title of a random node and perform a search in English.
-pub async fn search_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn search_en(user: &mut GooseUser) -> GooseTaskResult {
     // Build a random three-word phrase taken from english words on the Umami website.
     let search_words = common::random_words(3, true);
     let search_phrase = search_words.join(" ");
@@ -132,7 +132,7 @@ pub async fn search_en(user: &GooseUser) -> GooseTaskResult {
 }
 
 /// Load category listing by a random term in English and all static assets found on the page.
-pub async fn term_listing_en(user: &GooseUser) -> GooseTaskResult {
+pub async fn term_listing_en(user: &mut GooseUser) -> GooseTaskResult {
     let terms = common::get_terms();
     let term = terms.choose(&mut rand::thread_rng());
     let goose = user.get(term.unwrap().url_en).await?;
